<?php


namespace Controller;

use Traits\TResponse;
use Util\Utilities;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Service\Call as CallService;
use Zeedhi\DevOps\Util\Utilities as DevOpsUtilities;

class Call
{
    use TResponse;

    private $callService;

    public function __construct(CallService $callService) {
        $this->callService = $callService;
    }

    public function findCalls(Request $request, Response $response) {
        $param = $request->getParameters();

        ini_set('max_execution_time', '900');
        set_time_limit(900);
        try {
            $page = !empty($param['page']) ? $param['page']  : null;
            $limit = !empty($param['limit'])  ? $param['limit'] : null;
            $order = !empty($param['order'])  ? $param['order']  : null;
            $search = !empty($param['search'])  ? $param['search']  : null;
            $searchIn = !empty($param['search_in'])  ? $param['search_in']  : null;
            $find = !empty($param['find'])  ? $param['find']  : null;
            $dynamicFilter = !empty($param['dynamic_filter'])  ? $param['dynamic_filter'] : null;
            if(!empty($searchIn) && !empty($search)) {
                $columnsToRemove = array('CALL_WITHOUT_LABELS_CHECK', 'PRODUCT_FILTER_ID','NRCALLLABEL','CDOPERRESP','CLASSIFICATION');
                foreach ($columnsToRemove as $column) {
                    $pos = array_search($column, $searchIn);
                    if($pos) {
                        unset($searchIn[$pos]);
                    }
                }
            }
            $data = $this->callService->findFullCalls($dynamicFilter,$search, $searchIn, $find, $order, $page, $limit);
            $this->sendResponse($data, 200);
        } catch(\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function findCallsClosed(Request $request, Response $response) {
        $param = $request->getParameters();

        ini_set('max_execution_time', '900');
        set_time_limit(900);
        try {
            $page = !empty($param['page']) ? $param['page']  : null;
            $limit = !empty($param['limit'])  ? $param['limit'] : null;
            $order = !empty($param['order'])  ? $param['order']  : null;
            $search = !empty($param['search'])  ? $param['search']  : null;
            $searchIn = !empty($param['search_in'])  ? $param['search_in']  : null;
            $find = !empty($param['find'])  ? $param['find']  : null;
            $dynamicFilter = !empty($param['dynamic_filter'])  ? $param['dynamic_filter'] : null;
            if(!empty($searchIn) && !empty($search)) {
                $columnsToRemove = array('CALL_WITHOUT_LABELS_CHECK', 'PRODUCT_FILTER_ID','NRCALLLABEL','CDOPERRESP','CLASSIFICATION');
                foreach ($columnsToRemove as $column) {
                    $pos = array_search($column, $searchIn);
                    if($pos) {
                        unset($searchIn[$pos]);
                    }
                }
            }
            $data = $this->callService->findFullCallsClosed($dynamicFilter,$search, $searchIn, $find, $order, $page, $limit);
            $this->sendResponse($data, 200);
        } catch(\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function findCallComments(Request $request, Response $response) {
        try {
            $callType = $request->getParameter('CALL_TYPE');
            $callRelationship = $request->getParameter('CALL_RELATIONSHIP');
            $data = $this->callService->findCallComments($callRelationship, $callType);
            $this->sendResponse($data, 200);
        } catch(\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function findStatusIssue(Request $request, Response $response) {
        try {
            $data = $this->callService->findStatusIssue();
            $this->sendResponse($data, 200);
        } catch(\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function findStatusSoli(Request $request, Response $response) {
        try {
            $data = $this->callService->findStatusSoli();
            $this->sendResponse($data, 200);
        } catch(\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function findCallAttachments(Request $request, Response $response) {
        try {
            $callType = $request->getParameter('CALL_TYPE');
            $callRelationship = $request->getParameter('CALL_RELATIONSHIP');
            $param = $request->getParameters();
            $commentId = null;
            if(!empty($param['COMMENT_ID'])){
                $commentId = $param['COMMENT_ID'];
            }
            $filename  = null;
            if(!empty($param['FILENAME'])){
                $filename = $param['FILENAME'];
            }
            $data = $this->callService->findCallAttachments($callRelationship, $callType, $commentId, $filename);
            $this->sendResponse($data, 200);
        } catch(\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function getCall(Request $request, Response $response)
    {
        try {
            $callType = $request->getParameter('CALL_TYPE');
            $callRelationship = $request->getParameter('CALL_RELATIONSHIP');
            $call = $this->callService->getCall($callRelationship, $callType);
            $this->sendResponse(array("data" => $call), 200);
        }catch (\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function visualizeCall(Request $request, Response $response)
    {
        try {
            $rows = $request->getParameter('SELECTED_ROWS');
            $this->callService->visualizeCall($rows);
        }catch (\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function findProductCallProductsNew(Request $request, Response $response)
    {
        try {
            $param = $request->getParameters();
            $cdCliente = !empty($param['CDCLIENTE']) ? $param['CDCLIENTE'] : Utilities::getCdClienteBase();
            $callType = !empty($param['APPLICATION_TYPE']) ? $param['APPLICATION_TYPE'] : null;
            $callRelationship = !empty($param['CALL_RELATIONSHIP']) ? $param['CALL_RELATIONSHIP'] : null;
            $cdprodcomp = !empty($param['CDPRODCOMP']) ? $param['CDPRODCOMP'] : null;
            $productFilterId = !empty($param['search']) ? $param['search'] : null;
            $productId = !empty($param['PRODUCT_ID']) ? $param['PRODUCT_ID'] : null;
            if($productId !== $productFilterId){
                $productFilterId = null;
            }
            $productCallProducts = $this->callService->findProductCallProductsNew($cdCliente,  $callType, $callRelationship, $cdprodcomp,$productFilterId);
            $this->sendResponse($productCallProducts, 200);

        } catch(\Exception $e) {
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }

    public function findProductCallProductsfilter(Request $request, Response $response)
    {
        try {
            $param = $request->getParameters();
            $cdCliente = !empty($param['CDCLIENTE']) ? $param['CDCLIENTE'] : Utilities::getCdClienteBase();
            $callType = !empty($param['APPLICATION_TYPE']) ? $param['APPLICATION_TYPE'] : null;
            $callRelationship = !empty($param['CALL_RELATIONSHIP']) ? $param['CALL_RELATIONSHIP'] : null;
            $cdprodcomp = !empty($param['CDPRODCOMP']) ? $param['CDPRODCOMP'] : null;

            $productCallProducts = $this->callService->findProductCallProductsFilter($cdCliente,  $callType, $callRelationship, $cdprodcomp);
            $this->sendResponse($productCallProducts, 200);

        } catch(\Exception $e) {
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }

    public function findAllModules(Request $request, Response $response)
    {
        try {

            $productCallProducts = $this->callService->findAllModules();
            $this->sendResponse($productCallProducts, 200);

        } catch(\Exception $e) {
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }

    public function findProductCallProducts(Request $request, Response $response)
    {
        $params = $request->getParameters();
        try {
            $limit   = $params['limit'];
            $page    = $params['page'];

            $productCallProducts = array();
            $applicationType = $params['APPLICATION_TYPE'];
            $productType = empty($params['PRODUCT_TYPE']) ? null : $params['PRODUCT_TYPE'];

            if($applicationType === \Service\Call::TYPE_ISSUE) {
                $productCallProducts = $this->callService->findProductCallProducts();
            } else if ($applicationType === \Service\Call::TYPE_RICH_CLIENT) {
                if($productType) {
                    $productCallProducts = $this->callService->findProductCallProductsFromRichClient($productType, $params);
                }
            } else if ($applicationType === \Service\Call::TYPE_TICKET) {
                $productCallProducts = $this->callService->findProductCallProductsFromTicket($params);
            }
            $response->addDataSet(new DataSet('productCallProducts', $productCallProducts));

        } catch(\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage()));
        }
    }

    public function findProductCallClassification(Request $request, Response $response) {
        try {
            $productCallClassification = array();
            $applicationType =  $request->getParameter('APPLICATION_TYPE');

            if($applicationType === \Service\Call::TYPE_ISSUE) {
                $productCallClassification = $this->callService->findProductCallClassificationIssue();
            } else if($applicationType === \Service\Call::TYPE_RICH_CLIENT) {
                $productCallClassification = $this->callService->findProductCallClassificationFromRichClient();
            }
            $this->sendResponse($productCallClassification, 200);
        } catch(\Exception $e) {
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }

    public function findProductCallCdassunto(Request $request, Response $response) {
        try {
            $productCallClassification = $this->callService->findProductCallCdassunto();

            $this->sendResponse($productCallClassification, 200);
        } catch(\Exception $e) {
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }

    public function findProductCallProductTypes(Request $request, Response $response)
    {
        try {
            $productCode =  $request->getParameter('PRODUCT_CODE');

            $productCallProducTypes = $this->callService->findProductCallProductTypes($productCode);
            $this->sendResponse($productCallProducTypes, 200);
        } catch(\Exception $e) {
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }

    public function linkDownloadBudgetSm(Request $request, Response $response)
    {
        try {

            $param = $request->getParameters();
            $issueId = $param['ISSUE_ID'];
            $this->callService->getLinkDownloadBudgetSm($issueId);
        } catch(\Exception $e) {
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }

    public function openPageRequisite(Request\DataSet $request, Response $response)
    {
        try{
            $nrsoliserv = $request->getDataSet()->getRows()[0]['ID'];
            $this->callService->getPageRequisite($nrsoliserv);
        } catch(\Exception $e) {
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }

    public function findProductCallProductVersions(Request $request, Response $response)
    {
        try {
        $params = $request->getParameters();
        if(empty($params)) {
            $result = array(
                "pagination" => [
                    "total" => 2,
                    "page" => 1,
                    "limit" => 2
                ],
                "data" => []
            );
            $this->sendResponse($result, 200);
        } else {
            $product = $params["PRODUCT_TYPE"];
            if(!empty($params["CDARVPROD"]) && !empty($params["SGSISTEMA"]) ){
                $productCode = $params["CDARVPROD"].$params["SGSISTEMA"];
            } else {
                $productCode = $params["PRODUCT_CONCAT"];
            }

            $productCallProductVersions = $this->callService->findProductCalProductVersions($product, $product, $productCode);
            $this->sendResponse($productCallProductVersions, 200);
        }
        } catch(\Exception $e) {
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }

    public function findAllOperadorResponsible(Request $request, Response $response){
        try{
            $dataSet = $this->callService->findAllOperadorResponsible();
            $this->sendResponse($dataSet);
        } catch (\Exception $e) {
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }

    public function findAllCustomers(Request $request, Response $response){
        try{
            $dataSet = $this->callService->findAllCustomers();
            $this->sendResponse($dataSet);
        } catch (\Exception $e) {
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }

    public function findProductCallProductReleases(Request $request, Response $response){
        try{
            $params = $request->getParameters();
            $productType = $params["PRODUCT_TYPE"];
            $version = $params['PRODUCT_VERSION'];

            $productCallProductVersions = $this->callService->findProductCallProductReleases($productType, $version);
            $this->sendResponse($productCallProductVersions);
        } catch (\Exception $e) {
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }

    public function findProductCallProductPatch(Request $request, Response $response)
    {
        try {
            $params = $request->getParameters();

            $productType = $params["PRODUCT_TYPE"];
            $version = $params['PRODUCT_VERSION'];
            $release = $params['PRODUCT_RELEASE'];

            $productCallProductVersions = $this->callService->findProductCalProductPatch($productType, $version, $release);
            $this->sendResponse($productCallProductVersions);
        } catch (\Exception $e) {
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }

    public function findProductCallUseLicense(Request $request, Response $response)
    {
        try {

            $cdCliente =  $request->getParameter('CDCLIENTE');

            $productCallUserLicenses = $this->callService->findProductCallUseLicense($cdCliente);

            $this->sendResponse($productCallUserLicenses);
        } catch (\Exception $e) {
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }
    public function findAllCallLabels(Request $request, Response $response) {
        try {

            $callLabels = $this->callService->findAllCallLabels();
            $this->sendResponse($callLabels);
        } catch (\Exception $e) {
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }

    public function findMenuItems(Request $request, Response $response)
    {
        try{
            $productId =  $request->getParameter('PRODUCT_ID');
            $cdCliente =  $request->getParameter('CDCLIENTE');
            $menus = $this->callService->findMenuItems($productId,$cdCliente);
            $this->sendResponse($menus);
        } catch (\Exception $e) {
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }

    public function findProductVersion(Request $request, Response $response)
    {
        try{
            $productId =  $request->getParameter('PRODUCT_ID');
            $menus = $this->callService->findProductVersion($productId);
            $this->sendResponse($menus);
        } catch (\Exception $e) {
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }

    public function findProductVersionLtsWithoutBuild(Request $request, Response $response)
    {
        try {
            $parameters = $request->getParameters();
            $pmProjectId =  $parameters['PRODUCT_ID'];
            $cdcliente =  $parameters['CDCLIENTE'];
            $nrexternalProductId =  empty($parameters['NREXTERNAL_PRODUCT_ID']) ? null : $parameters['NREXTERNAL_PRODUCT_ID'];

            /** Caso especial do field que utiliza essa rota.
             * Qualquer alterações envlvendo esse campo
             * deve levar em considereção a lógica abaixo
             */
            if (isset($_REQUEST['search']) && $_REQUEST['search'] === 'Última versão' && in_array('ID', $_REQUEST['search_in'])) {
                $_REQUEST['search_in'] = array('VERSION');
            }

            $versions = $this->callService->findProductVersionLtsWithoutBuild($pmProjectId, $cdcliente, $nrexternalProductId);
            $this->sendResponse($versions, 200);
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function callsQueueSave(Request $request, Response $response) {
        try {
            $rows = $request->getParameters();
            $result = $this->callService->callsQueueSave($rows);
            $this->sendResponse($rows);
            } catch (\Exception $e) {
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }
    
    public function productCallSave(Request $request, Response $response)
    {
        ini_set('max_execution_time', '60');
        set_time_limit(60);
        try {
            $productCall = $request->getParameters();
            $id             = empty($productCall['ID']) ? null : $productCall['ID'];
            $callType       = empty($productCall['TYPE']) ? null : $productCall['TYPE'];
            $reference      = empty($productCall['REFERENCE']) ? null : $productCall['REFERENCE'];
            $product        = empty($productCall['PRODUCT']) ? null : $productCall['PRODUCT'];
            $projectId      = empty($productCall['PROJECT_ID']) ? null : $productCall['PROJECT_ID'];
            $board          = empty($productCall['BOARD']) ? null : $productCall['BOARD'];
            $classification = empty($productCall['CLASSIFICATION']) ? null : $productCall['CLASSIFICATION'];
            $description    = empty($productCall['DESCRIPTION']) ? null : $productCall['DESCRIPTION'];
            $callLabels     = empty($productCall['CALL_LABELS']) ? array() : $productCall['CALL_LABELS'];
            $productType    = empty($productCall['PRODUCT_TYPE']) ? null : $productCall['PRODUCT_TYPE'];
            $productVersion = isset($productCall['PRODUCT_VERSION']) ? $productCall['PRODUCT_VERSION'] : null;
            $productRelease = isset($productCall['PRODUCT_RELEASE']) ? $productCall['PRODUCT_RELEASE'] : null;
            $productPatch   = isset($productCall['PRODUCT_PATCH']) ? $productCall['PRODUCT_PATCH'] : null;
            $useLicense     = empty($productCall['USE_LICENSE']) ? null : $productCall['USE_LICENSE'];
            $reportedBy     = empty($productCall['REPORTED_BY']) ?  null : $productCall['REPORTED_BY'];
            $cdcliente      = empty($productCall['CDCLIENTE']) ?  null : $productCall['CDCLIENTE'];
            $appointmentDate     = empty($productCall['APPOINTMENT_DATE']) ?  null : \DateTime::createFromFormat(Utilities::FORMAT_DATE_DEFAULT_ONLY_DATE,$productCall['APPOINTMENT_DATE']);
            $devopsId = empty($productCall['DEVOPS_ID']) ? null : $productCall['DEVOPS_ID'];
            $menuItemId = empty($productCall['MENU_ITEM_ID']) ? null : $productCall['MENU_ITEM_ID'];
            $menuVersionId = empty($productCall['MENU_VERSION_ID']) ? null : $productCall['MENU_VERSION_ID'];
            $versionDevId = empty($productCall['VERSION_DEV_ID']) ? null : $productCall['VERSION_DEV_ID'];
            $nrsoliorig = empty($productCall['NRSOLIORIG']) ? null : $productCall['NRSOLIORIG'];
            if(empty($product)){
                $product = $projectId;
            }
            if(empty($reportedBy)){
                $reportedBy = empty($productCall['REPORTER_BY']) ?  null: $productCall['REPORTER_BY'];
            }

            $callRelationship = empty($productCall['CALL_RELATIONSHIP']) ? null : $productCall['CALL_RELATIONSHIP'];
            if(empty($classification)){
                $classification = empty($productCall['CDMOTICONT']) ? null : $productCall['CDMOTICONT'];
            }

            if(!$callRelationship){
                $newProductCall = $this->callService->saveNewProductCall($callType, $reference, $product, $productType,
                    $productVersion, $useLicense, $classification, $board, $description, $reportedBy,
                    $callLabels, $productRelease, $productPatch, $callRelationship,$devopsId,$menuItemId,$menuVersionId,
                    $cdcliente,null,$appointmentDate,$nrsoliorig);
                $productCall['ID'] = $newProductCall['ID'];
                $productCall['CALL_RELATIONSHIP'] = $newProductCall['CALL_RELATIONSHIP'];
            } else {
                $this->callService->updateProductCall($callType, $id,  $reference, $product, $productType, $productVersion,
                    $useLicense, $classification, $board, $description, $reportedBy, $callLabels, $devopsId, $menuItemId,
                    $menuVersionId, $cdcliente,$callRelationship,$appointmentDate,$productRelease,$productPatch, $versionDevId,$nrsoliorig);
            }
            $result = array(
                "pagination" => [
                    "total" => 2,
                    "page" => 1,
                    "limit" => 2
                ],
                "data" => $productCall
            );
            $this->sendResponse($result);
        } catch (\Exception $e) {
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }

    public function questionForSendCall(Request $request, Response $response)
    {
        try {
            $param = $request->getParameters();

            $lang = empty($param['LANG']) ? 'pt' : $param['LANG'];
            $callRelationship = empty($param['CALL_RELATIONSHIP']) ? null : $param['CALL_RELATIONSHIP'];
            $callType = empty($param['CALL_TYPE']) ? null : $param['CALL_TYPE'];

            $productCalls = $this->callService->getQuestionForSendCall($lang, $callType, $callRelationship);
            $this->sendResponse($productCalls);
        } catch (\Exception $e) {
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }

    public function getPatchFaseTram(Request $request, Response $response)
    {
        try {
            $param = $request->getParameters();

            $callRelationship = empty($param['CALL_RELATIONSHIP']) ? null : $param['CALL_RELATIONSHIP'];
            $callType = empty($param['CALL_TYPE']) ? null : $param['CALL_TYPE'];
            $productCalls = $this->callService->getPatchFaseTram($callType, $callRelationship);
            $this->sendResponse($productCalls);
        } catch (\Exception $e) {
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }

    public function getTransfPatchFaseTram(Request $request, Response $response)
    {
        try {
            $param = $request->getParameters();

            $callRelationship = empty($param['CALL_RELATIONSHIP']) ? null : $param['CALL_RELATIONSHIP'];
            $productCalls = $this->callService->getTransfPatchFaseTram($callRelationship);
            $this->sendResponse($productCalls);
        } catch (\Exception $e) {
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }

    public function delPatchFaseTram(Request $request, Response $response)
    {
        try {
            $param = $request->getParameters();

            $data = empty($param['data']) ? array() : $param['data'];
            $productCalls = $this->callService->delPatchFaseTram($data);
            $this->sendResponse($productCalls);
        } catch (\Exception $e) {
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }

    public function operadorByResponse(Request $request, Response $response)
    {
        try {
            $param = $request->getParameters();
            $callRelationship = empty($param['CALL_RELATIONSHIP']) ? null : $param['CALL_RELATIONSHIP'];
            $callType = empty($param['CALL_TYPE']) ? null : $param['CALL_TYPE'];
            $cdfastramdes = empty($param['CDFASTRAMDES']) ? null : $param['CDFASTRAMDES'];
            $nrfastramdes = empty($param['NRFASTRAMDES']) ? null : $param['NRFASTRAMDES'];
            $cdcliente = empty($param['CDCLIENTE']) ? null : $param['CDCLIENTE'];

            $productCalls = $this->callService->operadorByResponse($callType, $cdfastramdes, $nrfastramdes, $callRelationship,$cdcliente);
            $this->sendResponse($productCalls);
        } catch (\Exception $e) {
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }

    public function operadorChangeResponsible(Request $request, Response $response)
    {
        try {
            $param = $request->getParameters();
            $callRelationship = empty($param['CALL_RELATIONSHIP']) ? null : $param['CALL_RELATIONSHIP'];
            $cdcliente = empty($param['CDCLIENTE']) ? null : $param['CDCLIENTE'];

            $productCalls = $this->callService->operadorChangeResponsible( $callRelationship,$cdcliente);
            $this->sendResponse($productCalls);
        } catch (\Exception $e) {
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }

    public function closeSoliServ(Request $request, Response $response){
        try {
            $row                =  $request->getParameters();
            $callRelationship   = $row['CALL_RELATIONSHIP'];
            $document           = empty($row['DOCUMENT']) ?  array() : $row['DOCUMENT'];
            $callType           = 'S';
            $this->callService->closeSoliServ($callType, $callRelationship, $document);
        } catch (\Exception $e) {
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }

    public function sendCallGep(Request $request, Response $response)
    {
        try {
            $row                =  $request->getParameters();
            $cdfastramdes       = $row['CDFASTRAMDES'];
            $cdoperador         = $row['CDOPERADOR'];
            $comment            = $row['COMMENT'];
            $nrfastramdes       = $row['NRFASTRAMDES'];
            $txacaofatram       = $row['TXACAOFATRAM'];
            $callRelationship   = $row['CALL_RELATIONSHIP'];
            $document           = empty($row['DOCUMENT']) ? array() : $row['DOCUMENT'];
            $filePatch          = empty($row['FILE_PATCH']) ? array() : $row['FILE_PATCH'];
            $qryverficgpatch    = empty($row['QRYVERFICGPATCH']) ? array() : $row['QRYVERFICGPATCH'];
            $callType           = $row['CALL_TYPE'];
            $this->callService->sendCallGep(null, $cdfastramdes, $cdoperador, $comment, $nrfastramdes, $txacaofatram,
                $callType, $callRelationship, $document, $filePatch, $qryverficgpatch);
        } catch (\Exception $e) {
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }

    public function goBackStepGep(Request $request, Response $response)
    {
        try {
            $row                =  $request->getParameters();
            $callRelationship   = $row['CALL_RELATIONSHIP'];
            $callType           = $row['CALL_TYPE'];
            $this->callService->goBackStepGep($callType, $callRelationship);
        } catch (\Exception $e) {
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }

    public function sendChangeRespon(Request $request, Response $response)
    {
        try {
            $row                =  $request->getParameters();
            $cdoperador         = $row['CDOPERADOR'];
            $comment            = $row['COMMENT'];
            $callRelationship   = $row['CALL_RELATIONSHIP'];
            $this->callService->sendChangeRespon($cdoperador, $comment, $callRelationship);
        } catch (\Exception $e) {
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }

    public function findCurrentUser(Request $request, Response $response)
    {
        try {
            $this->sendResponse($this->callService->findCurrentUser());
        } catch (\Exception $e) {
            $this->sendResponse(['error' => $e->getMessage(), 'code' => $e->getCode()], 500);
        }
    }

}
